@@ -35,9 +35,7 @@ use Badger::Class
 sub export {
     my $class  = shift;
     my $target = shift;
-    $class->debug("export to $target: ", join(', ', @_)) if DEBUG;
-    my $params = @_ == 1 ? shift : { @_ };
-    my $schema = $class->schema($params);
+    my $schema = $class->schema(@_);
     
     $class->export_symbol(
         $target,
@@ -52,9 +50,10 @@ sub export {
     );
 }
 
+
 sub schema {
     my $class  = shift;
-    my $config = @_ == 1 ? (ref $_[0] eq ARRAY ? [@{$_[0]}] : shift) : [ @_ ];
+    my $config = @_ == 1 ? shift : { @_ };
     my ($name, $info, @aka, $fallback, $test, @schema);
 
     $class->debug("Generating schema from config: ", $class->dump_data($config))
@@ -63,45 +62,24 @@ sub schema {
     $config = [ split(DELIMITER, $config) ]
         unless ref $config;
     
-    $config = [ 
+    $config = { 
         map { 
-            my $k = $_;
-            my $v = $config->{ $k };
-            ref $v eq HASH
-                ? { name => $k, %$v } 
-                : { name => $k, default => $v }
-        } keys %$config
-    ] if ref $config eq HASH;
-
-#    $config = { 
-#        map { 
-#            ref($_) eq HASH 
-#                ? ($_->{ name } => $_)
-#                : ($_           => { })
-#        } @$config 
-#    } if ref $config eq ARRAY;
+            ref($_) eq HASH 
+                ? ($_->{ name } => $_)
+                : ($_           => { })
+        } @$config 
+    } if ref $config eq ARRAY;
 
     $class->debug("Canonical config: ", $class->dump_data($config))
         if DEBUG;
         
-#    while (($name, $info) = each %$config) {
-    while (@$config) {
-        $name = shift @$config;
-        $class->debug("config item: $name\n") if DEBUG;
-        if (ref $name eq HASH) {
-            $info = $name;
-            $name = $info->{ name };
+    while (($name, $info) = each %$config) {
+        if (ref $info eq HASH) {
+            # ok
         }
         else {
-            $info = { };
+            $info = { default => $info };
         }
-        $class->debug("name: $name   info: $info") if DEBUG;
-#        if (ref $info eq HASH) {
-#            # ok
-#        }
-#        else {
-#            $info = { default => $info };
-#        }
         
         $info->{ required } = 1 
             if $name =~ s/!$//;
@@ -143,7 +121,7 @@ sub schema {
     
     return \@schema;
 }
-
+    
 
 #-----------------------------------------------------------------------
 # this method is mixed into the target module
@@ -164,12 +142,11 @@ sub configure {
     ELEMENT: foreach $element (@$schema) {
         $name = $element->{ name };
         
-        FALLBACK: foreach $alias ($name, @{ $element->{ fallback } || [ ] }) {
-            next unless defined $alias;
+        FALLBACK: foreach $alias ($name, @{ $element->{ fallback } }) {
             if (ref $alias) {
                 $self->debug("Dispatching handler to set $name\n") if DEBUG;
                 ($code, @args) = @$alias;
-                ($ok, $value) = $code->($self, $class, $name, $config, $target, @args);
+                ($ok, $value) = $code->($self, $class, $name, $config, @args);
                 if ($ok) {
                     $target->{ $name } = $value;
                     next ELEMENT;
@@ -186,16 +163,13 @@ sub configure {
         }
         
         if (exists $element->{ default }) {
-            $self->debug("setting to default value: $element->{ default }\n") if DEBUG;
             $target->{ $name } = $element->{ default };
             next ELEMENT;
         }
         
         if ($element->{ required }) {
-            $self->debug("$name is required, throwing error\n") if DEBUG;
             return $self->error_msg( $element->{ error } || missing => $name );
         }
-        $self->debug("$name is not required, continuing\n") if DEBUG;
     }
     
     return $self;
@@ -214,7 +188,7 @@ sub configure {
 #-----------------------------------------------------------------------
     
 sub configure_pkg {
-    my ($self, $class, $name, $config, $target, $var) = @_;
+    my ($self, $class, $name, $config, $var) = @_;
     my $value = $class->var($var);
 
     $self->debug(
@@ -227,8 +201,9 @@ sub configure_pkg {
         : (NOTHING);
 }
 
+
 sub configure_class {
-    my ($self, $class, $name, $config, $target, $var) = @_;
+    my ($self, $class, $name, $config, $var) = @_;
     my $value = $class->any_var_in( split(':', $var) );
 
     $self->debug(
@@ -241,8 +216,9 @@ sub configure_class {
         : (NOTHING);
 }
 
+
 sub configure_env {
-    my ($self, $class, $name, $config, $target, $var) = @_;
+    my ($self, $class, $name, $config, $var) = @_;
     my $value = $ENV{ $var };
 
     $self->debug(
@@ -256,7 +232,7 @@ sub configure_env {
 }
 
 sub configure_method {
-    my ($self, $class, $name, $config, $target, $method) = @_;
+    my ($self, $class, $name, $config, $method) = @_;
 
     # see if the object has the required method - note we must call 
     # error_msg against CLASS (Badger::Class::Config) to use the 'bad_method'
@@ -277,22 +253,6 @@ sub configure_method {
         : (NOTHING);
 }
 
-sub configure_target {
-    my ($self, $class, $name, $config, $target, $var) = @_;
-
-    my $value = $target->{ $var };
-    
-    $self->debug(
-        "Looking for $var in $class target $target to set $name: ", 
-        defined $value ? $value : '<undef>'
-    ) if DEBUG;
-
-    return defined $value
-        ? (VALUE => $value)
-        : (NOTHING);
-}
-
-
 
 1;
 
@@ -402,7 +362,6 @@ call object methods.
         'bar|class:BAR',                # fallback to $BAR class var
         'baz|env:BAZ',                  # fallback to $BAZ environment var
         'bam|method:BAM';               # fallback to BAM() method
-        'wam|target:slam';              # fallback to $target->{ slam }
 
 Bear in mind that Perl implements constants using subroutines.  Thus, you
 can access a constant defined in a package/class by calling it as a
@@ -520,18 +479,13 @@ configuration options.
 This method is used internally to call object methods to return default
 configuration values.
 
-=head2 configure_target()
-
-This method is used internally to look inside the target object or hash array
-to return default configuration values.
-
 =head1 AUTHOR
 
 Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2008-2009 Andy Wardley.  All Rights Reserved.
+Copyright (C) 2008 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
