@@ -17,10 +17,11 @@ use Badger::Class
     debug     => 0,
     base      => 'Badger::Prototype Badger::Exporter',
     import    => 'class',
-    utils     => 'plural',
+    utils     => 'plural blessed textlike',
     words     => 'ITEM ITEMS ISA',
     constants => 'PKG ARRAY HASH REFS ONCE',
     constant  => {
+        OBJECT       => 'object',
         FOUND_REF    => 'found_ref',
         PATH_SUFFIX  => '_PATH',
     },
@@ -35,7 +36,9 @@ our $AUTOLOAD;
 our %LOADED;
 our %MAPPED;
 
-sub init {
+*init = \&init_factory;
+
+sub init_factory {
     my ($self, $config) = @_;
     my $class = $self->class;
     my ($item, $items, $path);
@@ -67,6 +70,8 @@ sub init {
     $self->{ items  } = $items;
     $self->{ item   } = $item;
 
+    $self->debug("Initialised $item/$items factory") if DEBUG;
+    
     return $self;
 }
 
@@ -91,12 +96,23 @@ sub item {
     my $self = shift->prototype;
     my ($type, @args) = $self->type_args(@_);
     my $items = $self->{ $self->{ items } };
-    
-    # massage $type to a canonical form
-    my $name = lc $type;
-       $name =~ s/\W//g;
-    my $item = $items->{ $name };
-    my $iref;
+    my ($name, $item, $iref);
+
+    # Modules like Template::TT2::Filterw allow the first argument to be 
+    # a code ref or object which implements the required behaviour.  If this
+    # is the case then we bypass the whole module lookup business and assume
+    # that we've been handed an object/ref that we otherwise would have 
+    # constructed.
+
+    if (textlike $type) {
+        # massage $type to a canonical form
+        $name = lc $type;
+        $name =~ s/\W//g;
+        $item = $items->{ $name };
+    }
+    else {
+        $name = $item = $type;
+    }
     
     # TODO: add $self to $config - but this breaks if %$config check
     # in Badger::Codecs found_ref_ARRAY
@@ -104,23 +120,31 @@ sub item {
     if (! defined $item) {
         # we haven't got an entry in the items table so let's try 
         # autoloading some modules using the module path
-        $item = $self->load($type)
+        $item = $self->load($type, @args)
             || return $self->error_msg( not_found => $self->{ item }, $type );
-        $item = $self->construct($item, @args);
+        $item = $self->construct($name, $item, @args);
     }
     elsif ($iref = ref $item) {
+        $iref = OBJECT if blessed $item;
+
+        $self->debug(
+            "Looking for handler methods: ", 
+            FOUND_REF,'_'.$iref, "() or ", 
+            FOUND_REF, "()"
+        ) if DEBUG;
+        
         my $method 
              = $self->can(FOUND_REF . '_' . $iref)
             || $self->can(FOUND_REF)
             || return $self->error_msg( bad_ref => $self->{ item }, $type, $iref );
             
-        $item = $method->($self, $item, @args) 
+        $item = $method->($self, $name, $item, @args) 
             || return;
     }
     else {
         # otherwise we load the module and create a new object
         class($item)->load unless $LOADED{ $item }++;
-        $item = $self->construct($item, @args);
+        $item = $self->construct($name, $item, @args);
     }
 
     return $self->found( $name => $item );
@@ -138,8 +162,9 @@ sub type_args {
 }
 
 sub construct {
-    shift;
-    shift->new(@_);
+    shift;            # $self
+    shift;            # $name
+    shift->new(@_);   # $class, @args
 }
     
 sub module_names {
@@ -186,13 +211,13 @@ sub load {
 }
 
 sub found_ref_ARRAY {
-    my ($self, $item, $config) = @_;
+    my ($self, $name, $item, @args) = @_;
     
     # default behaviour for handling a factory entry that is an ARRAY
     # reference is to assume that it is a [$module, $class] pair
     
     class($item->[0])->load unless $LOADED{ $item->[0] }++;
-    return $item->[1]->new($config);
+    return $self->construct($name, $item->[1], @args);
 }
 
 sub found {
@@ -206,7 +231,7 @@ sub can {
     $self = $self->prototype unless ref $self;
     
     if ($name eq $self->{ item }) {
-        return $self->can('item');
+        return $self->can('item');          # TODO: SUPER
     }
     elsif ($name eq $self->{ items }) {
         return $self->can('items');
@@ -229,6 +254,8 @@ sub AUTOLOAD {
 
     # upgrade class methods to calls on prototype
     $self = $self->prototype unless ref $self;
+
+    $self->debug("factory item: $self->{ item }\n") if DEBUG;
     
     if ($name eq $self->{ item }) {
         $self->class->method( $name => $self->can('item') );
@@ -344,7 +371,7 @@ TODO: examples
 
 TODO: Method to fetch or update the lookup table for mapping names to modules
 
-=head2 item($name, %params)
+=head2 item($name,@args)
 
 TODO: Method to load a module and insantiate an object.
 
@@ -357,7 +384,7 @@ to object constructor
 
 TODO: Method to load a module for an object type
 
-=head2 construct($class,@args)
+=head2 construct($name,$class,@args)
 
 TODO: Method to instantiate a $class object using the arguments provided.
 In the base class this method  simply calls:
@@ -368,7 +395,7 @@ In the base class this method  simply calls:
 
 TODO: Method to expand an object type into a candidate list of module names.
 
-=head2 found_ref_ARRAY($item,\@array)
+=head2 found_ref_ARRAY($name,$entry,@args)
 
 TODO: Method hook to handle the case of a factory entry defined as an 
 array reference.  It is assumed to be C<[$module, $class]>.  The C<$module>
@@ -376,7 +403,7 @@ is loaded and the C<$class> instantiated.
 
 Subclasses can re-define this to change this behaviour.
 
-=head2 found($item, $config)
+=head2 found($name,$item)
 
 TODO: Method hook to perform any post-processing (e.g. caching) after an
 item has been found and instantiated.
